#
# spec file for package libraw
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define debug_build   0
%define asan_build    0

%define tar_name LibRaw
%define lver    23
%define lname	libraw%{lver}
Name:           libraw
Version:        0.21.3
Release:        1.1
Summary:        Library for reading RAW files obtained from digital photo cameras
License:        CDDL-1.0 OR LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://www.libraw.org/
#Git-Clone:	git://github.com/LibRaw/LibRaw
Source0:        https://www.libraw.org/data/%tar_name-%version.tar.gz
Source1:        baselibs.conf
# CVE-2020-22628 [bsc#1215308], stretch() function in librawsrcpostprocessing
Patch0:         libraw-CVE-2020-22628.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
# zlib for deflate DNG support
BuildRequires:  zlib-devel

%description
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

LibRaw is based on the source codes of the dcraw utility, where part of
drawbacks have already been eliminated and part will be fixed in future.

%package tools
Summary:        Tools for reading RAW files obtained from digital photo cameras
Group:          Productivity/Graphics/Other

%description tools
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

LibRaw is based on the source codes of the dcraw utility, where part of
drawbacks have already been eliminated and part will be fixed in future.

%package -n %lname
Summary:        Library for reading RAW files obtained from digital photo cameras
Group:          System/Libraries

%description -n %lname
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

LibRaw is based on the source codes of the dcraw utility, where part of
drawbacks have already been eliminated and part will be fixed in future.

%package devel
Summary:        Development files for libraw
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

LibRaw is based on the source codes of the dcraw utility, where part of
drawbacks have already been eliminated and part will be fixed in future.

%package devel-static
Summary:        Library for reading RAW files obtained from digital photo cameras
Group:          Development/Libraries/C and C++
Requires:       %name-devel = %version

%description devel-static
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

LibRaw is based on the source codes of the dcraw utility, where part of
drawbacks have already been eliminated and part will be fixed in future.

This package contains static libraries that applications can use to build
against LibRaw. LibRaw does not provide dynamic libraries.

%prep
%autosetup -p1 -n %{tar_name}-%{version}

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export CXXFLAGS="%{optflags} -fPIC -DUSE_ZLIB"
export LDFLAGS="$LDFLAGS -pie"
%if %{debug_build}
export CXXFLAGS="$CXXFLAGS -O0"
%endif
export LIBS="$LIBS -lz"
autoreconf -fi
%configure
%if %{asan_build}
sed -i -e 's/\(^CXXFLAGS =.*\)/\1 -fsanitize=address/' \
       -e 's/\(^LIBS =.*\)/\1 -lasan/' \
       Makefile
%endif
make %{?_smp_mflags}

%install
find doc -type f -name "*.html" -exec chmod a-x "{}" "+"
mv doc manual
# The source tree has these with execute permissions for some reason
chmod -x Changelog.txt LICENSE.CDDL LICENSE.LGPL COPYRIGHT
chmod -x manual/index.html
# The Libraries
%make_install
find %buildroot -type f -name "*.la" -delete -print
# duplicated files
rm -rf %buildroot%_datadir/doc
%fdupes %buildroot/%_libdir

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files tools
%_bindir/*

%files devel
%doc Changelog.txt
%license COPYRIGHT LICENSE.CDDL LICENSE.LGPL
%doc manual
%_includedir/%name/
%_libdir/pkgconfig/*.pc
%_libdir/libraw.so
%_libdir/libraw_r.so

%files -n %lname
%_libdir/libraw.so.%{lver}*
%_libdir/libraw_r.so.%{lver}*

%files devel-static
%_libdir/libraw.a
%_libdir/libraw_r.a

%changelog
* Fri Jan 31 2025 ecsos <ecsos@opensuse.org>
- Update to 0.21.3:
  * new compile-time define LIBRAW_CALLOC_RAWSTORE
    If defined: calloc() will be used for all big buffer allocations
    to prevent uninitialized heap data leak
  * Small allocations: calloc() instead of malloc() to prevent
    uninitialized heap data leak
  * Support for 4-component JPEG-compressed DNG files
  * CR3-Qstep table: avoid wrong 64-bit code generation
  * Fixed several bugs related to specially-crafted files processing
    (thanks to OSS-Fuzz project)
* Mon Dec  2 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Limit fdupes to %%_libdir
* Thu Dec 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.21.2:
  * New compile-defined limit LIBRAW_MAX_PROFILE_SIZE_MB:
    limits allocation/read size for embedded color profile
    Embedded color profile allocation/read size: limited by input
    file size.
  * Multiple fixes (mostly inspired by oss-fuzz) to improve
    library stability and/or input checks.
  * raw-identify: use fallback if PATH_MAX not available
  * Disabled color conversion for Canon 16-bit thumbnails
  * docs/changelog: explained the case when no thumbnail is found
    in specific file
  * swapXX renamed to libraw_swapXX to avoid name conflict
  * better striped thumbnails handling
- drop libraw-CVE-2023-1729.patch (upstream)
* Thu Sep 14 2023 pgajdos@suse.com
- security update
- added patches
  fix CVE-2020-22628 [bsc#1215308], stretch() function in libraw/src/postprocessing/aspect_ratio.cpp
  + libraw-CVE-2020-22628.patch
* Tue May  2 2023 pgajdos@suse.com
- security update
- added patches
  fix CVE-2023-1729 [bsc#1210720], a heap-buffer-overflow in raw2image_ex()
  + libraw-CVE-2023-1729.patch
* Wed Jan 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.21.1:
  * fixed typo in panasonic metadata parser
  * Multiple fixes inspired by oss-fuzz project
  * Phase One/Leaf IIQ-S v2 support
  * Canon CR3 filmrolls
  * Canon CRM (movie) files
  * Tiled bit-packed (and 16-bit unpacked) DNGs
  * (non-standard) Deflate-compressed integer DNG files are allowed
  * Canon EOS R3, R7 and R10
  * Fujifilm X-H2S, X-T30 II
  * OM System OM-1
  * Leica M11
  * Sony A7-IV (ILCE-7M4)
  * DJI Mavic 3
  * Nikon Z9: standard compression formats only
* Wed Jan  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.21.0:
  * Camera format support:
    + Phase One/Leaf IIQ-S v2 support
    + Canon CR3 filmrolls/RawBurst
    + Canon CRM (movie) files
    + Tiled bit-packed (and 16-bit unpacked) DNGs
    + (non-standard) Deflate-compressed integer DNG files are allowed
  * Camera support:
    + Canon EOS R3, R7 and R10
    + Fujifilm X-H2S, X-T30 II
    + OM System OM-1
    + Leica M11
    + Sony A7-IV (ILCE-7M4)
    + DJI Mavic 3
    + Nikon Z9: standard compression formats only
  * Multiple (resultion) thumbnails support
  * Misc:
    + Nikon makernotes: read NEFCompression tag for HE/HE* files
    + Nikon orientation tag: more fixed offsets for known cameras
    + Adobe DNG SDK 1.6 support (meaning, just an additional patch for GPR SDK)
  * Bugs fixed:
    + Fixed possible out-of-buffer read in Nikon orientation tag parser
    + Out-of-range read-only array access in postprocessing if output_color is set to 0 (raw color)
    + Minolta Z2 was not recognized correctly on 32-bit systems
    + Fixed possible buffer overflow in Kodak C330 decoder
    + dcraw_process(): check for buffer allocation results to avoid NULL deref
    + Multiple bugfixes inspired by oss-fuzz project
* Mon Sep 27 2021 pgajdos@suse.com
- previous version updates fixed also:
  * CVE-2018-20337,CVE-2018-20363,CVE-2018-20364,CVE-2018-20365,
    CVE-2018-5815,CVE-2018-5816,CVE-2018-5817,CVE-2018-5818,
    CVE-2018-5819,CVE-2021-32142
  (bsc#1097975,bsc#1103206,bsc#1120498,bsc#1120499,bsc#1120500,
    bsc#1120515,bsc#1120516,bsc#1120517,bsc#1120519,bsc#1208470)
* Wed Apr 21 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Hardening: link as PIE (bsc#1184123).
* Fri Feb 19 2021 pgajdos@suse.com
- baselibs required by ImageMagick
- added sources
  + baselibs.conf
* Mon Oct 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.20.2:
  * corrected GPS EXIF output
  * Olympus XZ-1: do not provide linear_max
  * Pentax Optio 33WR: maker index was incorrect
  * dcraw_emu: corrected help line for -6 option.
  * raw-identify: corrected range check for color matrices print
  * use_camera_matrix option: fixed a bug introduced when making compiler more happy
  * multiple camera support improvements
* Fri Jul 24 2020 Paolo Stivanin <info@paolostivanin.com>
- version update to 0.20.0
  * Camera Format support
    + Canon CR3
    + GoPro (via GPR SDK)
    + Panasonic 14-bit
    + Fujifilm compressed/16bit
    + Rapsberry Pi RAW+JPEG format (if USE_6BY9RPI defined)
  * Camera support (+59, 1131 total)
    + Canon: PowerShot G5 X Mark II, G7 X Mark III, SX70 HS,
    + EOS R, EOS RP, EOS 90D, EOS 250D,  EOS M6 Mark II, EOS M50, EOS M200
    + EOS 1DX Mark III (lossless files only)
    + DJI Mavic Air, Osmo Action
    + FujiFilm GFX 100, X-A7, X-Pro3, X100V,
    X-T4 (uncompressed/lossless compressed only), X-T200
    + GoPro Fusion, HERO5, HERO6, HERO7, HERO8
    + Hasselblad L1D-20c, X1D II 50C
    + Leica D-LUX7, Q-P, Q2, V-LUX5, C-Lux / CAM-DC25, SL2, M10 Monochrom
    + Nikon D780, Z50, P950
    + Olympus TG-6, E-M5 Mark III, E-PL10, E-M1 Mark III,
    + Panasonic DC-FZ1000 II, DC-G90, DC-S1, DC-S1R, DC-S1H, DC-TZ95
    + PhaseOne IQ4 150MP
    + Ricoh GR III
    + Sony A7R IV, A9 II, ILCE-6100, ILCE-6600, RX0 II, RX100 VII
    + Zenit M
  * minor/unsorted changes
    + Add support for zlib during configure
    + Fixed multiple problems found by OSS-Fuzz
    + Lots of changes in imgdata.makernotes
    + DNG whitelevel calculated via BitsPerSample if not set via tags
    + DNG: support for LinearDNG w/ BlackLevelRepeat.. pattern
    + better support for Nikon Coolscan 16-bit NEF files
    + Bayer images: ensure that even margins have the same COLOR()
    for both the active sensor area and the full sensor area.
    + fixed several bugs
- removed libraw-Add-Sony-ILCE-7M3.patch
- removed libraw-CVE-2020-15503.patch
* Tue Jul  7 2020 pgajdos@suse.com
- security update
- added patches
  fix CVE-2020-15503 [bsc#1173674], lack of thumbnail size range check can lead to buffer overflow
  + libraw-CVE-2020-15503.patch
* Fri Dec 20 2019 pgajdos@suse.com
- version update to 0.19.5
  * LibRaw 0.19.5
  * WB coefficients check was too strong, weakened
  * Fixed possible buffer underrun in modern Samsung loader
  * LibRaw 0.19.4
  * CRW/metadata loop prevention code is rolled back due to ABI
    incompatibility. To enable, use -DLIBRAW_METADATA_LOOP_PREVENTION=1
    compile flag for LibRaw and ALL APPS.
  * Fixed possible buffer underflow
  * LibRaw 0.19.3
  * Several fixes inspired by OSS-Fuzz
- deleted patches
  - libraw-half-size-allocation-buffer-overflow.patch (upstreamed)
* Wed Aug 21 2019 pgajdos@suse.com
- drop JPEG2000 support [bsc#1144252]
* Fri Aug  2 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Thu Jan 10 2019 Petr Gajdos <pgajdos@suse.com>
- supplementary fix for https://github.com/LibRaw/LibRaw/issues/195
  + libraw-half-size-allocation-buffer-overflow.patch
* Tue Jan  8 2019 Petr Gajdos <pgajdos@suse.com>
- asan_build: build ASAN included
- debug_build: build more suitable for debugging
* Mon Dec 31 2018 Petr Gajdos <pgajdos@suse.com>
- Updated to version 0.19.2
  * Fixed possible buffer overrun at Fuji makernotes parser
  * Fixed possible write to NULL pointer at raw2image/raw2image_ex calls.
- ./configure not present in sources
* Tue Dec 11 2018 Petr Gajdos <pgajdos@suse.com>
- Updated to version 0.19.1
  * Finally: got Sinar 4shot sample, works fine now
  * OpenMP critical sections for malloc/free; extra #ifdefs
    removed; bin/dcraw_dist could be built again using Makefile.devel
  * additional checks in parse_phase_one()
  * more checks on file offsets/tag len in parse_minolta
  * more checks in parse_ciff
  * Mempool check reworked
  * Old Leaf (16bit/3color/TIFF) support
  * Fix cameraWB->autoWB fallback
  * Polaroid x530 channel swap; get metadata pointer for Foveon files
  * Fixed Secunia Advisory SA86384
  - possible infinite loop in unpacked_load_raw()
  - possible infinite loop in parse_rollei()
  - possible infinite loop in parse_sinar_ia()
- removed libraw-CVE-2018-5813.patch (upstreamed)
* Thu Aug  2 2018 asn@cryptomilk.org
- Add patch libraw-Add-Sony-ILCE-7M3.patch
  * See https://github.com/LibRaw/LibRaw/pull/145
  * The patch has been cut, the tarball from the download section
    doesn't match the git tag. dcraw/dcraw.c is totall different.
- Use %%license tag
* Wed Aug  1 2018 pgajdos@suse.com
- security update
  * CVE-2018-5813 [bsc#1103200]
    + libraw-CVE-2018-5813.patch
* Wed Aug  1 2018 pgajdos@suse.com
- new upstream branch, version 0.19.x
  * fixes CVE-2018-10529 and CVE-2018-10528, hence removing
    . libraw-CVE-2018-10528.patch
    . libraw-CVE-2018-10529.patch
  * the rest of changes at
    https://www.libraw.org/download#stable
* Mon Apr 30 2018 pgajdos@suse.com
- security update
  * CVE-2018-10528 [bsc#1091345]
    + libraw-CVE-2018-10528.patch
  * CVE-2018-10529 [bsc#1091346]
    + libraw-CVE-2018-10529.patch
* Mon Apr 30 2018 kbabioch@suse.com
- Updated to version 0.18.9:
  * samsung_load_raw: possible buffer overrun
  * rollei_load_raw: possible buffer overrun
  * nikon_coolscan_load_raw: possible buffer overrun, possible NULL pointer
  * find_green: possible stack overrun
  * parse_exif: possible stack overrun
* Fri Mar  9 2018 kbabioch@suse.com
- Updated to version 0.18.8:
  * leaf_hdr_load_raw: check for image pointer for demosaiced raw
  * NOKIARAW parser: check image dimensions readed from file
  * quicktake_100_load_raw: check width/height limits
- Dropped libraw-glibc-2.27.patch: No longer needed
* Fri Feb  9 2018 pgajdos@suse.com
- fix build with glibc 2.27 [bsc#1079853]
  + libraw-glibc-2.27.patch
* Tue Jan 23 2018 avindra@opensuse.org
- updated to 0.18.7:
  * All legacy (RGB raw) image loaders checks for imgdata.image is
    not NULL
  * kodak_radc_load_raw: check image size before processing
  * legacy memory allocator:
    allocate max(widh, raw_width) * max(height, raw_height)
- partial cleanup with spec-cleaner
- other spec fixes:
  * switch to https site
  * remove executable bit from copyright
  * remove outdated comment about build parallelism
* Thu Dec 14 2017 pgajdos@suse.com
- updated to 0.18.6:
  * Fixed fuji_width handling if file is neither fuji nor DNG
  * Fixed xtrans interpolate for broken xtrans pattern
  * Fixed panasonic decoder
* Mon Sep 25 2017 pgajdos@suse.com
- updated to 0.18.5:
    Fix for possible buffer overrun in kodak_65000 decoder
    Fix for possible heap overrun in Canon makernotes parser
    Fix for CVE-2017-13735
    CVE-2017-14265: Additional check for X-Trans CFA pattern data
- remove upstreamed libraw-out-of-bounds-kodak.patch
* Wed Sep 13 2017 pgajdos@suse.com
- updated to 0.18.4:
  * Fix for possible heap overrun in Canon makernotes parser
  (CVE-2017-14348)
  * Fix for CVE-2017-13735
  * CVE-2017-14265: Additional check for X-Trans CFA pattern data
- add libraw-out-of-bounds-kodak.patch, upstream bug #101
- remove libraw-CVE-2017-6887,6886.patch and
    libraw-CVE-2017-6890,6899.patch:
  no need to patch dcraw.c, it is not used
* Tue May 23 2017 pgajdos@suse.com
- updated to 0.18.2:
    Fixed several errors (Secunia advisory SA75000)
    ACES colorspace output option included in dcraw_emu help page
    Avoided possible 32-bit overflows in Sony metadata parser
    Phase One flat field code called even for half-size output
    Camera Support: Sigma Quattro H
    Fixed bug in FujiExpoMidPointShift parser
    Fixed wrong black level in Sony A350
    Added standard integer types for VisualStudio 2008 and earlier
- added missing parts of the fix for CVE-2017-6887
  and CVE-2017-6886
    + libraw-CVE-2017-6887,6886.patch
- added missing fix for CVE-2017-6890 and CVE-2017-6899
  + libraw-CVE-2017-6890,6899.patch
* Mon Jan 30 2017 pgajdos@suse.com
- renaming libraw15 to libraw16 and amend spec file to avoid such
  inconsistency [bsc#1021327]
* Wed Jan 11 2017 nico.kruber@gmail.com
- update to 0.18.0:
  * License changed to LGPL-2.1/CDDL-1.0
  * Camera support (+87):
    + Apple: iPad Pro, iPhone SE, iPhone 6s, iPhone 6 plus,
    iPhone 7, iPhone 7 plus
    + BlackMagic Micro Cinema Camera, URSA, URSA Mini
    + Canon PowerShot G5 X, PowerShot G7 X Mark II,
    PowerShot G9 X, IXUS 160 (CHDK hack), EOS 5D Mark IV,
    EOS 80D, EOS 1300D, EOS M10, EOS M5, EOS-1D X Mark II
    + Casio EX-ZR4000/5000
    + DXO One,
    + FujiFilm X-Pro2, X70, X-E2S, X-T2
    + Gione E7
    + GITUP GIT2
    + Google Pixel,Pixel XL
    + Hasselblad X1D, True Zoom
    + HTC MyTouch 4G, One (A9), One (M9), 10
    + Huawei P9
    + Leica M (Typ 262), M-D (Typ 262), S (Typ 007),
    SL (Typ 601), X-U (Typ 113), TL
    + LG G3, G4
    + Meizy MX4
    + Nikon D5, D500, D3400
    + Olympus E-PL8, E-M10 Mark II, Pen F, SH-3, E-M1-II
    + Panasonic DMC-G8/80/81/85, DMC-GX80/85,
    DMC-TZ80/81/85/ZS60, DMC-TZ100/101/ZS100,DMC-LX9/10/15,
    FZ2000/FZ2500
    + Pentax K-1, K-3 II, K-70
    + PhaseOne IQ3 100MP
    + RaspberryPi Camera, Camera V2
    + Ricoh GR II
    + Samsung Galaxy S7, S7 Edge
    + Sigma sd Quattro
    + Sony A7S II, ILCA-68 (A68), ILCE-6300, DSC-RX1R II,
    DSC-RX10III, DSC-RX100V,ILCA-99M2 (A99-II), a6500,
    IMX214, IMX219, IMX230, IMX298-mipi 16mp,
    IMX219-mipi 8mp, Xperia L
    + PtGrey GRAS-50S5C
    + YUNEEC CGO4
    + Xiaomi MI3, RedMi Note3 Pro
  * Floating point DNG support
  * More metadata parsed
  * Existing API changes:
    imgdata.params fields (all very specific purpose):
    sony_arw2_options, sraw_ycc, and params.x3f_flags
    replaced with single bit-field raw_processing_options
    See  LIBRAW_PROCESSING_* bits in documentation.
  * Fixed bug in Sony SR2 files black level
  * DNG files with BlackLevel both in vendor makernotes and
    BlackLevel: BlackLevel tag always takes precedence
  * ChannelBlackLevel added to canon makernotes
  * unpack_thumb() data size/offset check against file size
- removed libraw-0.17.1-gcc6-compatibility.patch (fixed upstream)
* Sun Jul 10 2016 nico.kruber@gmail.com
- update to 0.17.2:
  * strncpy usage was not compatible with glibc bounds check
* Tue May 24 2016 antoine.belvire@laposte.net
- Complete libraw-0.17.1-gcc6-compatibility.patch to fix build
  on ppc as well
* Tue May 24 2016 antoine.belvire@laposte.net
- Fix build with GCC 6:
  * Add libraw-0.17.1-gcc6-compatibility.patch
* Thu Dec  3 2015 pgajdos@suse.com
- updated to 0.17.1:
  * fixed two errors found by fuzzer (CVE-2015-8367)
  * phase_one_correct always returns value; handle P1 return codes
  in postprocessing
- removed upstreamedretval.diff
* Fri Nov 13 2015 jengelh@inai.de
- Update to new upstream release 0.17.0
  * Fixed dcraw.c ljpeg_start possibly buffer overrun
  * C API extension to support 3DLut Creator
  * More metadata parsing/extraction: XMP packet extracted (if
  exists), DNG Color information parsed, GPS data (partially)
  parsed, EXIF/Makernotes parsed for used optics (for both RAW
  files and DNG converted by Adobe convertor).
  * Exif/Makernotes parser callback (called for each processed tag)
  * Sony ARW2.3 decoder: params.sony_arw2_hack removed, decoded data
  are always in 0...17k range (note the difference with dcraw!);
  Additional processing options for Sony lossy compression techincal
  analysis.
  * Dcraw 9.26 imported (but some changes not approved because Libraw
  does it better) with some exceptions: no Pentax K3-II frame
  selection code; and no built-in JPEG decompressor.
  * Many improvements in data decoding/processing: Correct decoding
  of black level values from metadata for many formats, LibRaw does
  not rely on hardcoded black levels.
  * 224 camera models added to supported camera list. Some of them are
  new (released since LibRaw 0.16 come out), some was supported
  before, but missed from the list.
  * Fujifilm F700/S20Pro second frame support
- Add retval.diff to resolve new compiler warnings
* Sat Jun  6 2015 jengelh@inai.de
- Update to new upstream release 0.16.2
  * Fixed several bugs detected by running American Fuzzy Lop.
* Mon May 11 2015 pgajdos@suse.com
- updated to 0.16.1:
  * Fix for dcraw ljpeg_start() vulnerability.
* Thu Jan 30 2014 pgajdos@suse.com
- updated to 0.16.0:
  * removed 0001-build-fix-return-of-random-data.patch (upstreamed)
  * Support for new cameras:
    Baumer TXG14
    Blackmagic Cinema
    Canon EOS 70D, C500, S120, G16
    Fujifilm X-M1, X-A1, XE2, XQ1
    Hasselblad Lunar, Stellar
    Leica C, X VARIO
    Nikon D5200, P7800, D5300, D610, Df, 1 AW1
    Nokia Lumia 1020, 1520
    Olympus E-P5,E-M1, STYLUS1
    OmniVision OV5647 (Raspberry Pi)
    Panasonic LF1, GX7, GF6, GM1
    Pentax K-50, K-500, Q7,K-3
    Richon GR
    Samsung NX300, NX1100, NX2000, Galaxy NX (EK-GN120)
* Mon Sep  9 2013 pgajdos@suse.com
- updated to 0.15.4:
    Additional checks to data to prevent broken file opening
    New camera/format support:
    Richon GR
    Panasonic LF1
    Canon EOS 70D
    Sony RX100II, RX1R
    Olympus E-P5
* Mon Jul 29 2013 pgajdos@suse.com
- updated to 0.15.3:
  * New camera/format support:
    OmniVision OV5647 (Raspberry Pi)
    Nikon D5200
    Panasonic DMC-GF6
  * Fixed decoding error for some Canon sRAW files.
* Wed Jun 12 2013 pgajdos@suse.com
- remove libraw-gcc27.patch, it is upstreamed yet
* Tue Jun 11 2013 jengelh@inai.de
- Update to new upstream release 0.15.2
  * Fixed possible double-free() on error recovery on damaged
  full-color (Foveon, sRAW) files. (CVE-2013-2126, bnc#822665)
  * fixed wrong data maximum calculation for Panasonic files
  * check for possible buffer overrun in exposure correction code
  (CVE-2013-2127, bnc#822665)
- Add 0001-build-fix-return-of-random-data.patch
* Thu Jan 10 2013 jengelh@inai.de
- SONAME changed in 0.14, but prior update omitted package name
  change libraw2 -> libraw5. Do it now.
- Use more robust make install call
- Remove redundant %%clean section, and remove unused .la files
- Run fdupes to hardlink duplicate files
* Wed Jul 11 2012 lists.nico.k@googlemail.com
- update to 0.14.7
  * Imported dcraw 9.15 (1.449):
  - New cameras supported: Canon 5D Mark III, G1 X, 1D X and
    Powershot SX200; Nikon D4,D800/D800E and D3200; Fuji X-S1 and
    HS30EXR; Casio EX-Z8; Olympus E-M5; Panasonic GF5;
    Sony NEX-F3, SLT-A37 and SLT-A57; Samsung NX20 and NX210;
  - Support for updated Samsung NX200 firmware.
  * Makefile.msvc: easy additional compiler flag editing.
- update to 0.14.6
  * Casio EX-Z500 support
  * (possible) I/O exceptions on file open catched in
  open_datastream
  * Fixed possible read-after-buffer in Sony ARW2 decoder
  * Fixed mingw32 errors when compiling LibRaw_windows_datastream
  * Makefile.msvc: support of OpenMP and LCMS (uncomment to use)
  * Fixed decoding of some Leaf Aptus II files
- update to 0.14.5
  * Fixed bug (uninitialized variable) in SMAL format decoding.
  * Imported new dcraw 9.12 (1.446): support for Leica V-LUX 3,
  updated color data for Canon S100, Fujifilm X10, Nikon 1 J1/V1,
  Panasonic GX1, Samsung NX200, Sony NEX-7
- update to 0.14.4
  * Fixes to Panasonic/Leica file parser to prevent crash on
  broken jpegs.
  * Fixes to include order in src/libraw_datastream.cpp to better
  compile with KDEWIN
  * Floating-point DNGs are rejected on early processing stage.
  * Support for new cameras: Canon S100, Fuji X10, Panasonic GX1,
  Samsung NX200, Sony NEX-7.
- update to 0.14.3
  * Bug fixes in black level subtraction code for PhaseOne files
  * New API call LibRaw::get_internal_data_pointer() for developers
  who need access to libraw_internal_data fields
  (i.e. Fuji SuperCCD layout).
  * doc/API-overview fixes to reflect 0.14 changes
- update to 0.14.2
  * Fixed bug in Canon 1D and 1Ds files decoding.
  * New decoder information bit DECODER_HASRAWCURVE
- update to 0.14.1
  * Imported dcraw 9.11/1.445:
  - Support for new cameras added: Fujifilm F600EXR, Nikon P7100,
    Olympus E-PL3 and E-PM1, Panasonic DMC-FZ150, Sony NEX-5N,
    A65 and A77.
  - Updated color data for: Olympus E-P3, Panasonic G3 and GF3,
    PhaseOne H25, P40 and P65, Sony NEX-C3, NEX-5, NEX-3, A35
    and A55.
  - Support for dark frame extraction on Sony cameras.
  * DCB demosaicing: reserving 6 pixels instead of 3 to suppress
  colored image frame.
- update to 0.14.0
  * Multiple rendering (LibRaw::dcraw_process() calls) allowed
  without re-opening RAW file thrfough the sequence of
  open()/unpack() calls.
  You should be able to change any processing parameters
  (except shot_select parameter) between dcraw_process() calls.
  - New sample in samples/multirender_test.cpp: renders data 4 times:
    in half and full modes with different white balance settings.
  - Unprocessed RAW data is stored in separate data buffer:
    (2 bytes per pixel for all Bayer-pattern images, 8 bytes per
    pixel for Foveon, sRAW, and other full-color raw formats),
    so now LibRaw uses 25%% more memory for full processing of
    most common Bayer images; while for just unpack memory is
    reduced 4 times.
  - New call LibRaw::raw2image() fills imgdata.image array with
    fresh copy of data. There is no need to call raw2image()
    separately if you use dcraw_process() or
    dcraw_document_mode_processing() calls.
  - New call LibRaw::get_decoder_info() to determine raw data
    storage layout. See samples/unprocessed_raw.cpp for an example
    of how to use it.
  - New call LibRaw::free_image(), deallocates imgdata.image buffer.
    Use this call if current postprocessing results are not needed,
    but it is to early to call recycle() because dcraw_process()
    may be called later.
  - New C-API calls
    libraw_raw2image() - C API for LibRaw::raw2image()
    libraw_free_image() - C API for LibRaw::free_image()
    libraw_get_decoder_info() - C API for LibRaw::get_decoder_info()
  If your code uses usual open()/unpack()/dcraw_process() call
  sequence, then NOTHING CHANGED: your program should produce
  same results. For interactive programs you may skip open()/unpack()
  calls after adjusting processing parameters, so user should see
  image refreshed much faster.
  If your code uses raw data (open+unpack calls), you need to call
  LibRaw::raw2image(), and imgdata.image will contain same bitmap
  as in LibRaw 0.13.x
  If you code uses access to masked borders data, you need to
  rewrite it. See samples/unprocessed_raw.cpp as a sample.
  * Other changes:
  - No separate imgdata.masked_pixels buffers, Bayer raw formats
    are read to buffer with borders.
    So, no ugly add_masked_border_to_bitmap() call.
  - No filtering_mode parameter. Raw tone curve is applied at
    unpack() stage; zero pixels removed on postprocesing stage.
  - unprocessed_raw and 4colors samples are adjusted to use new
    RAW data storage layout.
  - OpenMP speedup of postprocessing steps (up to 50%% for half
    mode and 4-core machine)
  - Most of LibRaw_datastream function bodies are moved to
    separate source file
  - LibRaw_windows_datastream is merged to main source tree
  - Imported dcraw 9.10 (1.444), support for new cameras added:
    ARRIRAW format, Canon SX30 IS, Leica D-LUX 5 and V-LUX2,
    Olympus E-P3, Panasonic G3 and GF3, Sony NEX-C3 and SLT-A35
  - Support for RedOne digital movie cameras (R3D format).
    To enable this support you need to:
  * install libjasper JPEG2000 support library
  * compile LibRaw with -DUSE_JASPER compiler switch
    (./configure will do it for you)
  * If you use own LibRaw_datastream implementation, you should
    implement make_jas_stream() call for your datastream. See
    bottom of src/libraw_cxx.cpp for implementations in datafile
    and mem-buffer LibRaw streams.
  - Bugfix: green matching is turned off if output image is
    shrinked due to wavelet filtering or aberration correction.
  - Removed imgdata.sizes.bottom_margin and right_margin data
    fields use imgdata.sizes.raw_width - width - left_margin to
    get right one, the same with bottom_margin.
  - Minor ./configure cleanup
  - Qmake files and Visual Studio Project files are updated.
  - New version check macroses.
  - Documentation changed to reflect 0.14 changes.
  - Removed LibRaw::rotate_fuji_raw() call and corresponding
    C-API call.
  - The LibRaw::adjust_sizes_info_only() call may be called
    repeated and mixed with dcraw_process() calls.
  - Postprocessing speedup and optimization, especially
    if cropping set.
  - Cropping works for FujiCCD raws. For the technical reasons,
    the position of top-left corner of crop area will be rounded
    to the nearest multiple of 4 (the corner is shifted top-left).
  - New sample samples/postprocessing_benchmark.cpp This sample
    measures postprocessing speed. All demosaic methods, averaged
    white balance, median filtering, wavelet filtration, highlight
    recovery, and cropping are supported.
  * all client code should be recompiled due to internals change.
- update to 0.13.8
  * Imported dcraw 9.10 (1.444), support for new cameras added:
  ARRIRAW format, Canon SX30 IS, Leica D-LUX 5 and V-LUX2,
  Olympus E-P3, Panasonic G3 and GF3, Sony NEX-C3 and SLT-A35
  * Bugfix: green matching is turned off if output image is
  shrinked due to wavelet filtering or aberration correction.
- update to 0.13.7
  * Changes in cropping code:
  - cropping is now works for Fuji files (instead of crash)
  - bad pixels map and dark frame subtraction is turned off if
    cropping enabled
  - for technical reasons, coordinates of top-left corner of crop
    box are rounded to multiple of 4 for Fuji files.
  * ./configure stuff fixes:
  - install static libraries only when --enable-static is set
  - compiled samples are dynamically linked if shared library not
    disabled.
  * OpenMP enabled for Visual Studio 2008 SP1+, but not for RTM
- update to 0.13.6
  * Cosmetic cleanup in Libraw_memmgr code
  * Permit OpenMP support on MS VS2008
  * More general mem_image interface:
  - New call get_mem_image_format returns bitmap size and bit depth
  - New call copy_mem_image can copy bitmap into buffer with
    different color order (RGB/BGR) and line stride
  - dcraw_make_mem_image() uses calls mentioned above
  - see documentation for info on these function parameters.
  * libraw/librawwindows.h implements LibRaw_datastream class based
  on Windows memory mapped files.Win32/64-only Thanks to
  Linc Brookes.
  * Fixed parallel make errors in configure/Makefile.am
* Wed Mar 14 2012 dimstar@opensuse.org
- Add libraw-gcc47.patch: Fix build with gcc 4.7.
* Wed Aug 24 2011 idonmez@novell.com
- Stop using _service files
* Tue Aug  9 2011 toddrme2178@gmail.com
- Made html document file non-executable (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Sun Jun 12 2011 Nico.Laus.2001@gmx.de
- update to 0.13.5
  * Imported new dcraw 9.08/1.443:
    New color data for Canon 600D and 1100D, Fuji S200EXR
    New camera supported: Fuji HS20EXR and F550EXR, Kodak Z990,
    Nikon D5100, Olympus E-PL1s and XZ-1, Samsung NX11,
    Sony A230 and 290.
- update to 0.13.4
  * Imported new dcraw 9.07/1.442:
    support for Canon 600D and 1100D, Hasselblad H4D-60, Olympus E-PL2
  * Color data for Leaf Aptus II and Canon Powershot S2 IS
- update to 0.13.3
  * Preliminary support for Leaf Aptus II cameras (no color data yet):
    Leaf Aptus II 6,7,8,10 and 12 are tested, Aptus II 5 should work.
  * Preliminary support for Fujifilm X100 camera (again, no color data).
  * Fixed possible after the end of buffer read when working with
    in-memory RAW data.
  * Fixed possible loss of JPEG stream sync marks in LJPEG decoder
    (this bug was found only for Leaf Aptus II RAWs).
* Sun Mar 13 2011 coolo@novell.com
- update to 0.13.2
  * This version contains several big changes, improvements and bug fixes:
    New low-level buffering code for Huffman decompression. Canon CR2
    files are opened about 1.5x times faster than on LibRaw 0.12, other
    huffman-comressed files unpacks in 1.2-1.3 times faster.
    Exposure correction code based on linear-cubic root combination.
    Correction range is from 0.25 (-2 stops) to 8 (+3 stops)
    All 0.12.x features, including new cameras support and half-size/green-matching fixes.
    Changes and additions in demosaic-packs:
    Banding suppression code.
    High-frequency noise suppression.
    Green channels local averaging to suppress maze artifacts.
    OpenMP speed-up in median filters and green equilibration.
    Bug fixes and improvements:
    Better parsing of unknown command-line params in dcraw_emu sample
    Brigtness table in ahd_demosaic is calculated in reversed order to prevent
    possible (very unlikely) multithreaded app problem.
    Fixed file extension in half_mt.c sample.
    Fixed incomplete data fields reset in LibRaw::recycle()
    Patches for ./configure system for better LCMS2 support
- now provides shared library
* Fri Jan  7 2011 andreas.hanke@gmx-topmail.de
- simplify lcms2 build fix and rename to libraw-lcms2-build.patch, as
  it has nothing to do with the upstreamed libraw-pkg-config.patch
- remove duplicated documentation files rather than using fdupes
- build with -fPIC so the static archives can be linked into shared
  libraries/plugins (cf. http://www.libraw.org/node/535)
* Fri Jan  7 2011 adrian@suse.de
- Update to version 0.12.2
  * Fuji FinePix S5500 size adjusted to ignore (rare?) garbage
    at top of frame.
  * Sigma DPx processing disabled because of unsupported
    compession scheme and incompatible metadata format.
    These cameras will be supported only if dcraw will
    support them.
- use liblcms2 now
* Thu Dec 30 2010 andreas.hanke@gmx-topmail.de
- add libraw-pkg-config.patch to fix build issues in shotwell
  (already accepted upstream, cf. http://www.libraw.org/node/534)
* Sun Dec 12 2010 mrdocs@opensuse.org
-Update to version 0.12.0
-add libjpeg-devel to fix build on < 11.3
-drop default cflags patch - no longer needed with autotools
  + DCB interpolation and FBDD denoising integrated into main LibRaw.
  + Two addtional demosaic packs:   GPL2-licensed: AFD, LMMSE, VCD, Modified AHD and AHD+VCD interpolations.
  + Additional median filters from 'Modified DCRAW' package. Foveon support also included in this pack.
  + GPL3-licensed: AMaZE interpolation and chromatic aberrations correction from RawTherapee
  +LCMS 2.x support
  +New ./configure script, based on GNU autotools.
  +Bugfixes:Fix in green_matching code to support nonstandard Bayer pattern
  + Fixed bug in add_masked_borders_to_bitmap() call for cameras with masked border composed of odd number of pixels.
* Tue Nov 16 2010 mrdocs@opensuse.org
- add the right configure flags
* Tue Nov 16 2010 mrdocs@opensuse.org
-Update to version 0.11.2:
  +Imported dcraw 9.05 (1.439)
  + Support for many cameras added:
    Canon: G12, SX120, 60D
    Hasselblad H4D, Nokia X2, Olympus E-5
    Nikon: D3100, D7000, P7000
    Panasonic: FZ40, FZ100, LX5
    Pentax: K-r, K-5, 645D
    Samsung GX20, WB2000
-  added LCMS support so libRaw is color management capable
-  added openMP threading support for multi-core machines
* Wed Nov 10 2010 vuntz@opensuse.org
- Update to version 0.11.1:
  + Fixed bug in dcraw_emu sample command line processing
- Changes from version 0.11.0:
  + Processing pipeline has changed: black level is always
    subtracted on prostprocessing stage or by special
    subtract_black() call.
  + Cropping on postprocessing stage implemented.
  + New API call for clearing memory allocated by make_mem_image()
    call.
  + New iostreams based I/O layer, much faster on some systems
    (esp. Win32 and Linux).
  + Better exception handling code.
  + Secure FILE* I/O calls for Visual Studio 2008/2010.
  + Fixed bug with half_size processing.
  + Disabled OpenMP for wavelet_denoise under Mac OS X
  + Russian documentation re-coded to utf-8 from CP1251.
- Create a libraw-tools subpackage, containing command-line tools.
- Drop libraw-0.9.1-configure.patch: fixed upstream.
- Drop libraw-0.9.1-configure-optflags.patch: the changes in
  libraw-0.9.1-configure-default-cflags.patch make it useless.
- Update libraw-0.9.1-configure-default-cflags.patch to apply
  without libraw-0.9.1-configure-optflags.patch.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 0.10.0:
  + Imported dcraw versions 9.01-9.04 (1.434-1.438):
  - Separate black levels for each color channel.
  - Changes in tiff metadata parser.
  - New cameras: Canon SX20 and 550D, Nikon D3s, Olympus E-P2,
    Panasonic GF1, G2 and G10, Samsung EX1, NX-10 and WB550, Sony
    A450, NEX-3 and NEX-5, Casio EX-Z1050, Fuji HS10/HS11, Kodak
    Z981, Phase One P65.
  - Color data changed for some cameras
  - Fixed file descriptor leak in dark frame subtraction processing
  + Small patch in Sony ARW2 unpacking code to make valgrind happy
  + New command-line switch -h in mem_image sample (half_size
    support)
  + Some patches by Johannes Hanika (darktable author):
  - OpenMP speedup for PPG-interpolation
  - green_matching - suppress of 'color maze' on cameras with
    different green channels. This option is controlled by the
    field with the respective name in imgdata.params
  + all client code should be recompiled due to structures size change
  + LibRaw::free() is now public instead of private.
* Mon Aug 30 2010 vuntz@opensuse.org
- Split the static library files to a devel-static subpackage, to
  follow our packaging guidelines.
* Thu Aug 12 2010 vuntz@opensuse.org
- Clean up package for inclusion in openSUSE, based on the Fedora
  package and the one made by djs_core. This was version
  0.10.0-Beta3.
